import { router as StaticRouter } from './static'
import { router as StatRouter } from './stats'
import { router as SearchRouter } from './search'
import { router as TrackerRouter } from './tracker'
import express, { Application, Request, Response, NextFunction } from 'express';
import { join } from 'path';
import { auth } from 'r6-api';
import { connect } from 'mongoose';

var env = process.env.NODE_ENV || 'development';

if ('development' == env) {
    var {
        username,
        password,
        dburl
    } : { username: string, password: string, dburl: string } = require('./credentials.json')
} else {
    var username: string = process.env.UBISOFT_LOGIN_USERNAME!
    var password: string = process.env.UBISOFT_LOGIN_PASSWORD!
    var dburl: string = process.env.MONGODB_URL!
}

const app : Application = express()
const port: number | string = process.env.PORT || 3210;


const tokenFile = join(__dirname, 'token.json')
auth.init(tokenFile, username, password);

connect(dburl, { useNewUrlParser: true })
    .then(() => console.log('Connected to mongodb'))
    .catch(e => console.error(e))

app.use('/static', StaticRouter)
app.use('/stat', StatRouter)
app.use('/tracker', TrackerRouter)
app.use('/', SearchRouter)


if ('development' == env) {
    app.use((err: any, req: Request, res: Response, next: NextFunction) => {
        console.error(err.stack)
    
        next(err)
    })
}

app.use((err: any, req: Request, res: Response, next: NextFunction) => {
    const status = err.status || 500

    res.status(status).json({
        error: 'Internal server error',
        message: err.message
    })
})

app.listen(port, () => {
    console.log(`backend server started on port ${port}`)
})