import { Router } from "express";
import { resolver as UbiResolver } from './static'
import { HttpProfileResolver } from "r6-api";

const resolver = new HttpProfileResolver(UbiResolver)

export const router : Router = Router()

export class SearchRequestError extends Error { 
  status: number = 400

  constructor(message: string, status: number = 400) 
  {
    super(message)
    this.status = status
  }
}

router.get('/profile/search', async (req, res, next) => {
    if (req.query.name) {
      try {
        const profile = await resolver.search(req.query.name)
        res.json(profile)
      } catch (e) {
        next(e)
      }
    } else {
      next(new SearchRequestError('query parameter \"name\" expected'))
    }
})